%global cli_tool cplc

%global __requires_exclude ^java-headless.*$

Name:           classpathless-compiler
Version:        2.2
Release:        1%{?dist}
Summary:        Tool for recompiling java sources with customizable class providers
License:        ASL 2.0
URL:            https://github.com/mkoncek/classpathless-compiler
BuildArch:      noarch
ExclusiveArch:  %{java_arches} noarch

Source0:        https://github.com/mkoncek/classpathless-compiler/archive/refs/tags/%{version}.tar.gz

BuildRequires:  maven-local
BuildRequires:  java-11-openjdk-devel
BuildRequires:  mvn(com.beust:jcommander)
BuildRequires:  mvn(org.ow2.asm:asm-tree)

Requires:       java-11-headless
Requires:       javapackages-tools

%description
Classpathless compiler (CPLC) is a compiler wrapper used for compiling java
sources with customizable class providers. This tool works differently from the
traditional java compiler in that it doesn't use provided classpath but instead
pulls dependencies using an API.

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n classpathless-compiler-%{version}

find -name '*.java' -exec sed -i '/@SuppressFBWarnings\|import edu\.umd\.cs\.findbugs/d' {} +

sed -i 's/org\.objectweb\.asm\.Opcodes\.ASM9/org.objectweb.asm.Opcodes.ASM6/' util/src/main/java/io/github/mkoncek/classpathless/util/BytecodeExtractor.java
sed "s/    justification = .*//" -i api/src/main/java/io/github/mkoncek/classpathless/api/IdentifiedSource.java

%pom_remove_dep :spotbugs-annotations

%pom_remove_plugin :maven-assembly-plugin impl
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_remove_plugin :spotbugs-maven-plugin

%build
export JAVA_HOME=/usr/lib/jvm/java-11
%mvn_build -f

%install
%mvn_install

%jpackage_script io.github.mkoncek.classpathless.Tool "" "" classpathless-compiler/classpathless-compiler:classpathless-compiler/classpathless-compiler-api:classpathless-compiler/classpathless-compiler-util:beust-jcommander %{cli_tool}

%files -f .mfiles
%{_bindir}/%{cli_tool}

%license LICENSE
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE

%changelog
* Wed Jan 18 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.2
- bumped to 2.2 

* Fri Jan 07 2022 Marian Koncek <mkoncek@redhat.com> - 2.1.1-1
- Update to upstream version 2.1.1

* Thu Aug 12 2021 Marian Koncek <mkoncek@redhat.com> - 1.4-4
- Fix Requires

* Fri Aug 06 2021 Marian Koncek <mkoncek@redhat.com> - 1.4-3
- Rebuild

* Fri Aug 06 2021 Marian Koncek <mkoncek@redhat.com> - 1.4-2
- Fix BuildRequires on java-11-headless

* Thu Jul 22 2021 Marian Koncek <mkoncek@redhat.com> - 1.4-1
- Update to upstream version 1.4

* Tue Jul 13 2021 Marian Koncek <mkoncek@redhat.com> - 1.3-1
- Initial release
